

#### APIview Concept Logics
'''
from django.shortcuts import render
from employees.models import Employee
from employees.serializers import EmployeeModelSerializer

from rest_framework.views import APIView
from rest_framework.response import Response
from rest_framework import status 


class EmployeeListView(APIView):
    def get(self, request): # db ---> queryset --->> dict ---->> json ---> browser/App2
        employee_list = Employee.objects.all()  # <QuerySet [{},{},..]> | <QuerySet []>
        
        serializer = EmployeeModelSerializer(employee_list, many=True) # python type dict
        
        return Response(serializer.data, status=status.HTTP_200_OK)
    
    
    def post(self, request): # browser --> json ---> dict ---> queryset --->> db
        serializer = EmployeeModelSerializer(data=request.data)
        
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data, status=status.HTTP_201_CREATED)
        else:
            return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
        
        
class EmployeeDetailView(APIView):
    def get(self,request,pk): # db ---> queryset --->> dict ---->> json ---> browser/App2
        try:
            employee = Employee.objects.get(id=pk) # Object | DoesNotExit
        except Employee.DoesNotExist:
            data = {
                "message" : "Requested employee is not available for reading"
            }
            return Response(data, status=status.HTTP_404_NOT_FOUND)
        else:
            serializer = EmployeeModelSerializer(employee)

            return Response(serializer.data, status=status.HTTP_200_OK)

    def put(self,request,pk):
        try:
            employee = Employee.objects.get(id=pk) # Object | DoesNotExit
        except Employee.DoesNotExist:
            data = {
                "message" : "Requested employee is not available for update"
            }
            return Response(data, status=status.HTTP_404_NOT_FOUND)
        else:
            serializer = EmployeeModelSerializer(employee,data=request.data)

            if serializer.is_valid():
                serializer.save()
                return Response(serializer.data, status=status.HTTP_200_OK)
            else:
                return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)

    def delete(self,request,pk):
        try:
            employee = Employee.objects.get(id=pk) # Object | DoesNotExit
        except Employee.DoesNotExist:
            data = {
                "message" : "Requested employee is not available for delete"
            }
            return Response(data, status=status.HTTP_404_NOT_FOUND)
        else:
            employee.delete()
            data = {
                "message": "Requested employee is deleted successfully"
            }
            return Response(data, status=status.HTTP_204_NO_CONTENT)
'''


### Developing APIs using  mixins  concept
'''
from employees.models import Employee
from employees.serializers import EmployeeModelSerializer

from rest_framework import mixins, generics

class EmployeeListView(mixins.ListModelMixin, mixins.CreateModelMixin, generics.GenericAPIView):
    queryset = Employee.objects.all()
    serializer_class = EmployeeModelSerializer

    def get(self,request):
        return self.list(request)

    def post(self,request):
        return self.create(request)


class EmployeeDetailView(mixins.RetrieveModelMixin, mixins.UpdateModelMixin,
                         mixins.DestroyModelMixin, generics.GenericAPIView):
    queryset = Employee.objects.all()
    serializer_class = EmployeeModelSerializer

    def get(self,request,pk):
        return self.retrieve(request)

    def put(self,request,pk):
        return self.update(request)

    def delete(self, request,pk):
        return self.destroy(request)
'''


### Developing APIs using generics module concept
'''
from employees.models import Employee
from employees.serializers import EmployeeModelSerializer
from rest_framework import  generics

class EmployeeListView(generics.ListCreateAPIView):
    queryset = Employee.objects.all()
    serializer_class = EmployeeModelSerializer

class EmployeeDetailView(generics.RetrieveUpdateDestroyAPIView):
    queryset = Employee.objects.all()
    serializer_class = EmployeeModelSerializer
'''

### Developing APIs using viewsets module concept

from employees.models import Employee
from employees.api.serializers import EmployeeModelSerializer
from rest_framework import viewsets

class EmployeeView(viewsets.ModelViewSet):
    queryset = Employee.objects.all()
    serializer_class = EmployeeModelSerializer


















        
            
            
         

        